@@ -5,6 +5,7 @@
 """
 test the build system
 """
+from rez.config import config
 from rez.build_process import create_build_process
 from rez.build_system import create_build_system
 from rez.resolved_context import ResolvedContext
@@ -136,16 +137,22 @@ class TestBuild(TestBase, TempdirMixin):
 
     @per_available_shell()
     @install_dependent()
-    def test_build_whack(self):
-        """Test that a broken build fails correctly."""
+    def test_build_whack(self, shell):
+        """Test that a broken build fails correctly.
+        """
+        config.override("default_shell", shell)
+
         working_dir = os.path.join(self.src_root, "whack")
         builder = self._create_builder(working_dir)
         self.assertRaises(BuildError, builder.build, clean=True)
 
     @per_available_shell()
     @install_dependent()
-    def test_builds(self):
-        """Test an interdependent set of builds."""
+    def test_builds(self, shell):
+        """Test an interdependent set of builds.
+        """
+        config.override("default_shell", shell)
+
         self._test_build_build_util()
         self._test_build_floob()
         self._test_build_foo()
@@ -154,8 +161,11 @@ class TestBuild(TestBase, TempdirMixin):
 
     @per_available_shell()
     @install_dependent()
-    def test_builds_anti(self):
-        """Test we can build packages that contain anti packages"""
+    def test_builds_anti(self, shell):
+        """Test we can build packages that contain anti packages
+        """
+        config.override("default_shell", shell)
+
         self._test_build_build_util()
         self._test_build_floob()
         self._test_build_anti()
